@@ -26,8 +26,8 @@ smart_match = {
 }
 
 OPERATOR_LIST = [
-        (' ([+',    '+',    '+])= '),
-        (' ([-',    '-',    '-])=> '),
+        (' ([+',    '+',    '+])= ',        '(\+\+\w)|(\w\+\+)'),
+        (' ([-',    '-',    '-])=> ',       '(--\w)|(\w--)'),
         (' ([/*',   '*',    ':NOTHING:',    '[\[\{\( ]\*{2,}'),
         (' (/*',    '/',    '*/= ',         '<\w+?\/\w+?\.h>'),
         ('< ',      '<',    ':ALL:'),
